%% in short: this function extends a linearly independent set (columns of A) to a basis of a vector space (the span of the columns of B)
%%
%% in detail:
%% A = a matrix, the columns of which are to be thought of as a collection of linearly independent vectors
%% B = a matrix, the columns of which are to be thought of as a collection of vectors
%% assume that the columns of A span a subspace of the span of the columns of B
%% the function returns another matrix C; the columns of C have the property that they contain the columns of A and form a basis for the span of the columns of B
%%

function C=linIndSetToBasis(A,B)
	C=A; % start with C=A
	[rows columns]=size(B);
	for i=1:columns
		if ~isInSpan(C,B(:,i))
			C=[C B(:,i)];
		end
	end
end
